regulators: Clear error history when powering on

Enhance the Manager class to clear error history when powering on the
system.  Clear all data on previously logged errors.  If the error
occurs again in the future, it will be logged again.

When the system is powered off, hardware may be replaced that fixes the
problem.  Thus, errors are cleared during power on.

Tested:
* Verified that error history is cleared when system is powered on.

Signed-off-by: Shawn McCarney <shawnmm@us.ibm.com>
Change-Id: Id174458ec3649819f8e7127c16039d535c42dd1e
diff --git a/phosphor-regulators/src/manager.cpp b/phosphor-regulators/src/manager.cpp
index 1bdc9ab..8385b28 100644
--- a/phosphor-regulators/src/manager.cpp
+++ b/phosphor-regulators/src/manager.cpp
@@ -225,9 +225,10 @@
     {
         // Clear any cached hardware data in the System object
         system->clearCache();
-    }
 
-    // TODO: Clear error history related to hardware devices
+        // Clear error history related to hardware devices in the System object
+        system->clearErrorHistory();
+    }
 }
 
 void Manager::findCompatibleSystemTypes()